local ADDON, data = ...

function Intoxicated_CreateOptions ()
    -- Default values!
    g_Intoxicated_config = g_Intoxicated_config or {}
    g_Intoxicated_config.scale = g_Intoxicated_config.scale or 1.0
    
    local Options = CreateFrame ("Frame", "IntoxicatedOptions", UIParent);
    Options.name = "Intoxicated";
    Options:Hide ()
    InterfaceOptions_AddCategory (Options);
    
    Options.refresh = function ()
        self.sldScale:SetValue (g_Intoxicated_config.scale)
        Options.chkHideOutOfCombat:SetChecked (g_Intoxicated_config.hideOutOfCombat)
        Options.chkClickThrough:SetChecked (g_Intoxicated_config.clickThrough)
    end

    local Title = Options:CreateFontString (nil, "ARTWORK", "GameFontNormalLarge")
    Title:SetPoint ("TOPLEFT", 10, -16)
    Title:SetText (Options.name)
    Options.Title = Title

    
    -- Misc
    local TitleMisc = Options:CreateFontString (nil, "ARTWORK", "GameFontHighlight")
    TitleMisc:SetPoint("TOPLEFT", Title, "BOTTOMLEFT", -2, -10)
    TitleMisc:SetText ('Miscellaneous:')
    Options.TitleMisc = TitleMisc

    
    -- Scale
    Options.lblScale = Options:CreateFontString (nil, "ARTWORK", "GameFontHighlight")
    Options.lblScale:SetPoint("TOPLEFT", TitleMisc, "BOTTOMLEFT", 8, -10)
    Options.lblScale:SetText ('Scale')
    
    Options.sldScale = CreateFrame ("Slider", 'IntoxicatedOptionsScale', Options, "OptionsSliderTemplate")
    Options.sldScale:SetSize (200, 16)
    Options.sldScale:SetPoint ("TOPLEFT", Options.lblScale, "BOTTOMLEFT", 0, -6)
    Options.sldScale:SetMinMaxValues (0.5, 1.5)
    Options.sldScale:SetValueStep (0.1)
    Options.sldScale:SetValue (g_Intoxicated_config.scale)
    Options.sldScale:SetObeyStepOnDrag (true) 
    
    Options.sldScale:SetScript ("OnValueChanged", function (self, value)
        g_Intoxicated_config.scale = value
        frmIntoxicated:SetScale (value)
    end)
    
    -- Hide out of combat
    Options.chkHideOutOfCombat = CreateFrame ("CheckButton", nil, Options, "InterfaceOptionsCheckButtonTemplate")
    Options.chkHideOutOfCombat:SetPoint ("TOPLEFT", TitleMisc, "BOTTOMLEFT", 3, -97)
    Options.chkHideOutOfCombat.Text:SetText ("Hide out of combat")
    Options.chkHideOutOfCombat:SetChecked (g_Intoxicated_config.hideOutOfCombat)
    Options.chkHideOutOfCombat:SetScript ("OnClick", function (self, ...)
        g_Intoxicated_config.hideOutOfCombat = self:GetChecked ()
        if g_Intoxicated_config.hideOutOfCombat  and  (not UnitAffectingCombat('player')) then
            frmIntoxicated:Hide ()
        end
        if not g_Intoxicated_config.hideOutOfCombat then
            frmIntoxicated:Show ()
        end
    end)
    Options.chkHideOutOfCombat:SetScript("OnEnter", function(self, motion, ...)
        GameTooltip:SetOwner (self, "ANCHOR_TOPLEFT")
        GameTooltip:AddLine ('Hide out of combat', 1, 1, 0)
        GameTooltip:AddLine ('If this option is enabled, the entire add-on will be invisible when out of combat', 1, 1, 1)
        GameTooltip:Show ()
    end)
    Options.chkHideOutOfCombat:SetScript("OnLeave", function(self, motion, ...)
        GameTooltip:Hide ()
    end)

    -- Click-through
    Options.chkClickThrough = CreateFrame ("CheckButton", nil, Options, "InterfaceOptionsCheckButtonTemplate")
    Options.chkClickThrough:SetPoint ("TOPLEFT", TitleMisc, "BOTTOMLEFT", 3, -122)
    Options.chkClickThrough.Text:SetText ("Click-through")
    Options.chkClickThrough:SetChecked (g_Intoxicated_config.clickThrough)
    Options.chkClickThrough:SetScript ("OnClick", function (self, ...)
        g_Intoxicated_config.clickThrough = self:GetChecked ()
        frmIntoxicated:toggleLock (g_Intoxicated_config.clickThrough)
    end)
    Options.chkClickThrough:SetScript("OnEnter", function(self, motion, ...)
        GameTooltip:SetOwner (self, "ANCHOR_TOPLEFT")
        GameTooltip:AddLine ('Click-through', 1, 1, 0)
        GameTooltip:AddLine ('When this option is enabled, the add-on is not movable and you can click through it', 1, 1, 1)
        GameTooltip:Show ()
    end)
    Options.chkClickThrough:SetScript("OnLeave", function(self, motion, ...)
        GameTooltip:Hide ()
    end)

end

